Hello community,

here is the log from the commit of package python-zetup for openSUSE:Factory 
checked in at 2018-08-31 10:46:23
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/python-zetup (Old)
 and      /work/SRC/openSUSE:Factory/.python-zetup.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "python-zetup"

Fri Aug 31 10:46:23 2018 rev:2 rq:632144 version:0.2.43

Changes:
--------
--- /work/SRC/openSUSE:Factory/python-zetup/python-zetup.changes        
2018-05-15 10:31:25.040561795 +0200
+++ /work/SRC/openSUSE:Factory/.python-zetup.new/python-zetup.changes   
2018-08-31 10:46:23.159343211 +0200
@@ -1,0 +2,6 @@
+Wed Aug 29 11:26:34 UTC 2018 - [email protected]
+
+- Update to 0.2.43:
+  * Various entry point fixes
+
+-------------------------------------------------------------------

Old:
----
  zetup-0.2.42.tar.gz

New:
----
  zetup-0.2.43.tar.gz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ python-zetup.spec ++++++
--- /var/tmp/diff_new_pack.U9aqPi/_old  2018-08-31 10:46:23.603343752 +0200
+++ /var/tmp/diff_new_pack.U9aqPi/_new  2018-08-31 10:46:23.619343772 +0200
@@ -13,36 +13,32 @@
 # published by the Open Source Initiative.
 
 # Please submit bugfixes or comments via http://bugs.opensuse.org/
+#
 
 
 %{?!python_module:%define python_module() python-%{**} python3-%{**}}
-%bcond_without test
 Name:           python-zetup
-Version:        0.2.42
+Version:        0.2.43
 Release:        0
-License:        LGPL-3.0
 Summary:        Project setups tools
-Url:            https://github.com/zimmermanncode/zetup
+License:        LGPL-3.0-only
 Group:          Development/Languages/Python
+URL:            https://github.com/zimmermanncode/zetup
 Source:         
https://files.pythonhosted.org/packages/source/z/zetup/zetup-%{version}.tar.gz
-BuildRequires:  python-rpm-macros
-BuildRequires:  %{python_module devel}
-BuildRequires:  %{python_module setuptools}
-BuildRequires:  %{python_module setuptools_scm >= 1.15}
-BuildRequires:  fdupes
-%if %{with test}
-BuildRequires:  %{python_module path.py >= 10.3}
 BuildRequires:  %{python_module jupyter_nbconvert >= 5.2}
+BuildRequires:  %{python_module path.py >= 10.3}
 BuildRequires:  %{python_module pytest}
-%endif
-Recommends:     python-path.py >= 10.3
+BuildRequires:  %{python_module setuptools_scm >= 2.0}
+BuildRequires:  %{python_module setuptools}
+BuildRequires:  fdupes
+BuildRequires:  python-rpm-macros
+Requires(post): update-alternatives
+Requires(postun): update-alternatives
 Recommends:     python-jinjatools >= 0.1.7
 Recommends:     python-jupyter_nbconvert >= 5.2
+Recommends:     python-path.py >= 10.3
 Recommends:     python-pytest
 BuildArch:      noarch
-Requires(post):   update-alternatives
-Requires(postun):  update-alternatives
-
 %python_subpackages
 
 %description
@@ -62,12 +58,12 @@
 
 %python_clone -a %{buildroot}%{_bindir}/zetup
 
-%if %{with test}
 %check
+export PYTHONDONTWRITEBYTECODE=1
+# test_python - checks if python is set by maintainer to be supported, bogus
 %{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
-py.test-%{$python_bin_suffix} test/
+py.test-%{$python_bin_suffix} test/ -k 'not test_python'
 }
-%endif
 
 %post
 %python_install_alternative zetup
@@ -76,7 +72,6 @@
 %python_uninstall_alternative zetup
 
 %files %{python_files}
-%defattr(-,root,root,-)
 %doc README.ipynb README.md README.rst
 %license COPYING COPYING.LESSER
 %python_alternative %{_bindir}/zetup

++++++ zetup-0.2.42.tar.gz -> zetup-0.2.43.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/PKG-INFO new/zetup-0.2.43/PKG-INFO
--- old/zetup-0.2.42/PKG-INFO   2017-08-24 14:52:41.000000000 +0200
+++ new/zetup-0.2.43/PKG-INFO   2018-04-18 17:16:50.000000000 +0200
@@ -1,6 +1,6 @@
-Metadata-Version: 1.1
+Metadata-Version: 2.1
 Name: zetup
-Version: 0.2.42
+Version: 0.2.43
 Summary: Zimmermann's Extensible Tools for Unified Project_setups
 Home-page: https://github.com/zimmermanncode/zetup
 Author: Stefan Zimmermann
@@ -17,7 +17,10 @@
 Classifier: Topic :: Utilities
 Classifier: Programming Language :: Python
 Classifier: Programming Language :: Python :: 2.7
-Classifier: Programming Language :: Python :: 3.3
 Classifier: Programming Language :: Python :: 3.4
 Classifier: Programming Language :: Python :: 3.5
 Classifier: Programming Language :: Python :: 3.6
+Provides-Extra: commands
+Provides-Extra: notebook
+Provides-Extra: pytest
+Provides-Extra: all
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/VERSION new/zetup-0.2.43/VERSION
--- old/zetup-0.2.42/VERSION    2017-08-24 14:52:41.000000000 +0200
+++ new/zetup-0.2.43/VERSION    2018-04-18 17:16:50.000000000 +0200
@@ -1 +1 @@
-0.2.42
\ No newline at end of file
+0.2.43
\ No newline at end of file
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/requirements.txt 
new/zetup-0.2.43/requirements.txt
--- old/zetup-0.2.42/requirements.txt   2017-08-24 14:51:13.000000000 +0200
+++ new/zetup-0.2.43/requirements.txt   2018-04-18 17:15:38.000000000 +0200
@@ -1,2 +1 @@
-# setuptools
-setuptools_scm >= 1.15
+setuptools_scm >= 2.0
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/setup.py new/zetup-0.2.43/setup.py
--- old/zetup-0.2.42/setup.py   2017-08-24 14:51:13.000000000 +0200
+++ new/zetup-0.2.43/setup.py   2018-04-18 17:15:38.000000000 +0200
@@ -8,7 +8,8 @@
 
 
 def samefile(path, other):
-    """Workaround for missing ``os.path.samefile`` in Windows Python 2.7
+    """
+    Workaround for missing ``os.path.samefile`` in Windows Python 2.7.
     """
     return os.path.normcase(os.path.normpath(os.path.realpath(path))) \
         == os.path.normcase(os.path.normpath(os.path.realpath(other)))
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetup/__init__.py 
new/zetup-0.2.43/zetup/__init__.py
--- old/zetup-0.2.42/zetup/__init__.py  2017-08-24 14:51:13.000000000 +0200
+++ new/zetup-0.2.43/zetup/__init__.py  2018-04-18 17:15:38.000000000 +0200
@@ -26,10 +26,9 @@
 import sys
 
 import pkg_resources
-#HACK: happens on setup of namespace packages
-if pkg_resources.require is None:
-    # might be needed by package requirements
-    pkg_resources.require = pkg_resources.WorkingSet().require
+# pkg_resources might not be fully populated yet during setup of namespaces
+pkg_resources.iter_entry_points = pkg_resources.WorkingSet().iter_entry_points
+pkg_resources.require = pkg_resources.WorkingSet().require
 
 
 from .zetup import Zetup, find_zetup_config
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetup/notebook/jinja.py 
new/zetup-0.2.43/zetup/notebook/jinja.py
--- old/zetup-0.2.42/zetup/notebook/jinja.py    2017-08-24 14:51:13.000000000 
+0200
+++ new/zetup-0.2.43/zetup/notebook/jinja.py    2018-04-18 17:15:38.000000000 
+0200
@@ -25,6 +25,12 @@
 from jinja2 import BaseLoader, TemplateNotFound
 
 
+def smart_prompts(source, prompt='>>> ', cont='... '):
+    return '\n'.join(
+        (not re.match(r'^\s', line) and prompt or cont) + line
+        for line in source.split('\n'))
+
+
 def bitbucket_rst_links(rst):
     return re.sub(
       r'<#[0-9.-]+([^>]+)>',
@@ -41,9 +47,10 @@
 
 
 FILTERS = {
-  'bitbucket_rst_links': bitbucket_rst_links,
-  'github_markdown_links': github_markdown_links,
-  }
+    'smart_prompts': smart_prompts,
+    'bitbucket_rst_links': bitbucket_rst_links,
+    'github_markdown_links': github_markdown_links,
+}
 
 
 class ExtraTemplateLoader(BaseLoader):
@@ -64,9 +71,9 @@
         {%- endif %}
 
         {% if cell.outputs and not cell.source.startswith(('%', '!')) -%}
-        {{ cell.source | add_prompts(cont='>>> ') | indent }}
+        {{ cell.source | smart_prompts | indent }}
         {%- else -%}
-        {{ cell.source | indent }}
+        {{ cell.source | smart_prompts | indent }}
         {%- endif %}
         {%- endif %}
         {% endblock input %}
@@ -101,9 +108,9 @@
         {%- endif %}
         {%- endif %}
         {% if cell.outputs and not cell.source.startswith(('%', '!')) -%}
-        {{ cell.source | add_prompts(cont='>>> ') }}
+        {{ cell.source | smart_prompts }}
         {%- else -%}
-        {{ cell.source }}
+        {{ cell.source | smart_prompts }}
         {% if not cell.outputs -%}
         ```
         {%- endif %}
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetup/process/__init__.py 
new/zetup-0.2.43/zetup/process/__init__.py
--- old/zetup-0.2.42/zetup/process/__init__.py  2017-08-24 14:51:13.000000000 
+0200
+++ new/zetup-0.2.43/zetup/process/__init__.py  2018-04-18 17:15:38.000000000 
+0200
@@ -43,10 +43,12 @@
 if sys.platform.startswith('win'):
 
     def _where(command):
-        """Try to find the executable file path of given `command`
-        using ``where.exe``.
         """
-        if os.path.isabs(command):
+        Try to find the executable file path of given `command` using
+        ``where.exe``.
+        """
+        # just accept commands with any absolute or relative directory prefix
+        if os.path.dirname(command):
             return command
 
         out = subprocess.Popen(
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetup/zetup_config.py 
new/zetup-0.2.43/zetup/zetup_config.py
--- old/zetup-0.2.42/zetup/zetup_config.py      2017-08-24 14:52:41.000000000 
+0200
+++ new/zetup-0.2.43/zetup/zetup_config.py      2018-04-18 17:16:50.000000000 
+0200
@@ -28,7 +28,7 @@
 
 TITLE = 'zetup'
 
-PYTHON = ['2.7', '3.3', '3.4', '3.5', '3.6']
+PYTHON = ['2.7', '3.4', '3.5', '3.6']
 
 MODULES = []
 
@@ -147,8 +147,7 @@
 ], zfg=zfg)
 
 REQUIRES = Requirements("""
-# setuptools
-setuptools_scm >= 1.15
+setuptools_scm >= 2.0
 
 """, zfg=zfg)
 
@@ -156,7 +155,7 @@
 
 SETUP_HOOKS = []
 
-VERSION = Version('0.2.42')
+VERSION = Version('0.2.43')
 
 KEEP_MADE = []
 
@@ -176,4 +175,4 @@
 
 DISTRIBUTION = Distribution(zfg)
 
-CLASSIFIERS = ['Development Status :: 3 - Alpha', 'Intended Audience :: 
Developers', 'License :: OSI Approved :: GNU Library or Lesser General Public 
License (LGPL)', 'Operating System :: OS Independent', 'Topic :: Software 
Development', 'Topic :: Utilities', 'Programming Language :: Python', 
'Programming Language :: Python :: 2.7', 'Programming Language :: Python :: 
3.3', 'Programming Language :: Python :: 3.4', 'Programming Language :: Python 
:: 3.5', 'Programming Language :: Python :: 3.6']
\ No newline at end of file
+CLASSIFIERS = ['Development Status :: 3 - Alpha', 'Intended Audience :: 
Developers', 'License :: OSI Approved :: GNU Library or Lesser General Public 
License (LGPL)', 'Operating System :: OS Independent', 'Topic :: Software 
Development', 'Topic :: Utilities', 'Programming Language :: Python', 
'Programming Language :: Python :: 2.7', 'Programming Language :: Python :: 
3.4', 'Programming Language :: Python :: 3.5', 'Programming Language :: Python 
:: 3.6']
\ No newline at end of file
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetup.egg-info/PKG-INFO 
new/zetup-0.2.43/zetup.egg-info/PKG-INFO
--- old/zetup-0.2.42/zetup.egg-info/PKG-INFO    2017-08-24 14:52:41.000000000 
+0200
+++ new/zetup-0.2.43/zetup.egg-info/PKG-INFO    2018-04-18 17:16:50.000000000 
+0200
@@ -1,6 +1,6 @@
-Metadata-Version: 1.1
+Metadata-Version: 2.1
 Name: zetup
-Version: 0.2.42
+Version: 0.2.43
 Summary: Zimmermann's Extensible Tools for Unified Project_setups
 Home-page: https://github.com/zimmermanncode/zetup
 Author: Stefan Zimmermann
@@ -17,7 +17,10 @@
 Classifier: Topic :: Utilities
 Classifier: Programming Language :: Python
 Classifier: Programming Language :: Python :: 2.7
-Classifier: Programming Language :: Python :: 3.3
 Classifier: Programming Language :: Python :: 3.4
 Classifier: Programming Language :: Python :: 3.5
 Classifier: Programming Language :: Python :: 3.6
+Provides-Extra: commands
+Provides-Extra: notebook
+Provides-Extra: pytest
+Provides-Extra: all
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetup.egg-info/requires.txt 
new/zetup-0.2.43/zetup.egg-info/requires.txt
--- old/zetup-0.2.42/zetup.egg-info/requires.txt        2017-08-24 
14:52:41.000000000 +0200
+++ new/zetup-0.2.43/zetup.egg-info/requires.txt        2018-04-18 
17:16:50.000000000 +0200
@@ -1,4 +1,4 @@
-setuptools_scm>=1.15
+setuptools_scm>=2.0
 
 [all]
 path.py>=10.3
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetuprc new/zetup-0.2.43/zetuprc
--- old/zetup-0.2.42/zetuprc    2017-08-24 14:51:13.000000000 +0200
+++ new/zetup-0.2.43/zetuprc    2018-04-18 17:15:38.000000000 +0200
@@ -8,7 +8,7 @@
 
 license = LGPLv3
 
-python = 2.7 3.3 3.4 3.5 3.6
+python = 2.7 3.4 3.5 3.6
 
 scripts =
     zetup: zetup.script:run


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/zetup-0.2.42/zetup/modules.py 
new/zetup-0.2.43/zetup/modules.py
--- old/zetup-0.2.42/zetup/modules.py   2017-08-24 14:51:13.000000000 +0200
+++ new/zetup-0.2.43/zetup/modules.py   2018-04-18 17:15:38.000000000 +0200
@@ -17,10 +17,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with zetup.py. If not, see <http://www.gnu.org/licenses/>.
 
-"""zetup.modules
+"""
+zetup.modules
 
-Module object wrappers for packages, top-level packages,
-and top-level packages for extra features.
+Module object wrappers for packages, top-level packages, and top-level
+packages for extra features
 
 .. moduleauthor:: Stefan Zimmermann <[email protected]>
 """
@@ -42,16 +43,20 @@
 
 
 class deprecated(str):
-    """Simple ``str`` class wrapper for marking a
-       :class:`zetup.package` api member (alias) name as deprecated.
+    """
+    Simple ``str`` class wrapper for indicating deprecation.
+
+    Marks a :class:`zetup.package` API member (alias) name as deprecated
     """
     def __repr__(self):
         return "deprecated(%s)" % str.__repr__(self)
 
 
 class package(ModuleType, object):
-    """Package module object wrapper
-       for clean dynamic API import from sub-modules.
+    """
+    Package module object wrapper.
+
+    For clean dynamic API import from sub-modules
     """
     __module__ = __package__
 
@@ -60,17 +65,20 @@
             aliases=None, deprecated_aliases=None,
             __getitem__=None, __iter__=None, __call__=None
     ):
-        """Wraps a package module given by its `name`.
+        """
+        Wraps a package module given by `name`.
+
+        Original package module object is replaced in ``sys.modules`` and
+        stored in :attr:``.__module__``
 
-        - Original package module object is replaced in ``sys.modules``
-          and stored in :attr:``.__module__``.
-        - Optional `__all__` list defines the package API.
-        - Optional `aliases` and `deprecated_aliases`
-          map alternative names to API names.
-        - `__getitem__`, `__iter__`, and `__call__` features
-          can be added to the package wrapper
-          by providing handler functions or other callable objects
-          (which are not called with a 'self' argument).
+        Optional `__all__` list defines the package API
+
+        Optional `aliases` and `deprecated_aliases` map alternative names to
+        API names
+
+        `__getitem__`, `__iter__`, and `__call__` features can be added to the
+        package wrapper by providing handler functions or other callable
+        objects (which are not called with a ``self`` argument)
         """
         mod = sys.modules[name]
         ModuleType.__init__(self, name, mod.__doc__)
@@ -131,7 +139,8 @@
 
     @property
     def __all__(self):
         """Get API member name list (without deprecated aliases).
         """
         return list(set(chain(
             getattr(self.__module__, '__all__', ()),
@@ -140,8 +149,9 @@
 
     def __setattr__(self, name, value):
         """
-        Prevent submodules from being added as attributes to avoid
-        unnecessary ``dir()`` pollution.
+        Prevent submodules from being added as attributes.
+
+        To avoid unnecessary ``dir()`` pollution
         """
         if isinstance(value, AutoDocScopeModule) or ismodule(value) and (
                 value.__name__ == '%s.%s' % (self.__name__, name)
@@ -154,8 +164,8 @@
         object.__setattr__(self, name, value)
 
     def __getattribute__(self, name):
-        """Dynamically access API from wrapped module
-           or import extra API members.
+        """
+        Dynamically access API from wrapped module or import extra API.
         """
         if name.startswith('__'):
             try:
@@ -195,13 +205,15 @@
         return obj
 
     def __dir__(self):
-        """Additionally get all API member names.
+        """
+        Additionally get all API member names
         """
         def exclude():
-            """Get names of submodules which were implicitly added
-               to this package wrapper's ``__dict__``
-               by ``from .submodule import ...`` statements in wrapped module
-               following the wrapper instantiation.
+            """
+            Get names of submodules implicitly added to ``__dict__``.
+
+            Which happens on ``from .submodule import ...`` statements in
+            wrapped module following the wrapper instantiation
             """
             for name, obj in self.__dict__.items():
                 if name.startswith('__'):
@@ -215,7 +227,8 @@
             self.__all__))
 
     def __repr__(self):
-        """Create module-style representation.
+        """
+        Create module-style representation
         """
         return "<%s %s from %s>" % (
             type(self).__name__, repr(self.__name__),
@@ -223,9 +236,11 @@
 
 
 class toplevel(package):
-    """Special top-level package module object wrapper
-       for clean dynamic API import from sub-modules
-       and automatic application of func:`zetup.annotate`.
+    """
+    Special top-level package module object wrapper.
+
+    For clean dynamic API import from sub-modules and automatic application
+    of func:`zetup.annotate`
     """
     __module__ = __package__
 
@@ -233,14 +248,14 @@
             self, name, __all__=None,
             aliases=None, deprecated_aliases=None,
             check_requirements=True, check_packages=True,
-            __getitem__=None, __iter__=None, __call__=None
-    ):
-        """Wrap top-level package module given by its `name`
-           and `api` member list.
+            __getitem__=None, __iter__=None, __call__=None):
+        """
+        Wrap top-level package module given by `name` and `api` list.
+
+        See :class:`zetup.package` for details about defining the package
+        API and special features
 
-        - See :class:`zetup.package`
-          for details about defining the package API and special features.
-        - See :func:`zetup.annotate` for details about the check options.
+        See :func:`zetup.annotate` for details about the check options
         """
         super(toplevel, self).__init__(
             name, __all__,
@@ -268,9 +283,11 @@
         # PY2/3 compatible way to assign metaclass
         extra_toplevel_meta('extra_toplevel_base', (package, ), {})
 ):
-    """Special extra feature top-level package module object wrapper
-       for clean dynamic API import from sub-modules
-       and automatic application of func:`zetup.annotate_extra`.
+    """
+    Special extra feature top-level package module object wrapper.
+
+    For clean dynamic API import from sub-modules and automatic application
+    of func:`zetup.annotate_extra`
     """
     __module__ = __package__
 
@@ -280,12 +297,13 @@
             check_requirements=True,
             __getitem__=None, __iter__=None, __call__=None
     ):
-        """Wrap top-level package module given by its `name`
-           and `api` member list.
+        """
+        Wrap top-level package module given by `name` and `api` list.
+
+        See :class:`zetup.package` for details about defining the package
+        API and special features
 
-        - See :class:`zetup.package`
-          for details about defining the package API and special features.
-        - See :func:`zetup.annotate_extra` for details about the check option.
+        See :func:`zetup.annotate_extra` for details about the check option
         """
         super(extra_toplevel, self).__init__(
             name, __all__,
@@ -131,7 +139,8 @@
     @property
     def __all__(self):
-        """Get API member name list (without deprecated aliases).
+        """
+        Get API names list (without deprecated aliases).
         """
         return list(set(chain(